/* Copyright (C) 2006 P.L. Lucas
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA. 
 */

#include <QtGui>	
#include <QApplication> 
#include <QWidget>
#include <QMap>
#include <QApplication>

#include "mainwindow.h"
#include "navigator.h"  
#include "editor.h" 	
#include "terminal.h"   
#include "config.h"

MainWindow::MainWindow(OctaveConnection *oc, QWidget *parent):QMainWindow(parent)
{
	setWindowTitle("QtOctave");
	resize(QSize(800, 600).expandedTo(minimumSizeHint()));
	this->octave_connection=oc;
	setAttribute(Qt::WA_DeleteOnClose);	
	
	modeWorkArea = get_config("mode_work_area");
	
	createActions();
	
	closeMessage = new QMessageBox("QtOctave", 
			"Your changes will have effect, when QtOctave reboot.\
			\n Do you want to do it?", QMessageBox::Question, QMessageBox::Yes | QMessageBox::Default, QMessageBox::No, QMessageBox::NoButton
			, this, Qt::Dialog | Qt::MSWindowsFixedSizeDialogHint);

	if(modeWorkArea == NULL)
	{
		modeWorkArea = "workspace";
		windowSettings["mode_work_area"] = modeWorkArea;
		set_config(windowSettings);
	}
	

	if(modeWorkArea == "workspace")
	{
		work_space = new QMdiArea(this);
		work_space->setHorizontalScrollBarPolicy (Qt::ScrollBarAsNeeded);
		work_space->setVerticalScrollBarPolicy (Qt::ScrollBarAsNeeded);
		work_space->show();
		setCentralWidget(work_space);
	}
	else if(modeWorkArea == "dock")
	{
		work_space=NULL;
#if QT_VERSION < 0x040200
		QWidget *widget=new QWidget(this);
		setCentralWidget(widget);
		widget->setMaximumSize (0, 0 );
		widget->setSizeIncrement ( 0, 0 );
		widget->setSizePolicy (QSizePolicy::Fixed,QSizePolicy::Fixed);
		widget->show();
#else
		//centralWindow = new QMainWindow;
		//setCentralWidget(centralWindow);
		setCentralWidget(new QMainWindow);
#endif
		createDockWindows();
	}
	else if(modeWorkArea == "sdi")
	{
		work_space=NULL;
	}
	
	createMenus();	
	createStatusBar();	
	createToolBars();
	
	if(modeWorkArea == "dock")
	{
		QString home=QDir::home().path()+"/.qtoctave/";
		{
			QFile file(home+"qtoctave_state.dat");
			if (file.open(QIODevice::ReadOnly | QIODevice::Text))
			{
				QByteArray data=file.readAll();
				if(restoreState(data))
				{
					//printf("Restaurado\n");
				}
				file.close();
			}
		}
		{
			QFile file(home+"qtoctave_central_state.dat");
			if (file.open(QIODevice::ReadOnly | QIODevice::Text))
			{
				QByteArray data=file.readAll();
				if(((QMainWindow*)centralWidget())->restoreState(data))
				{
					//printf("Restaurado\n");
				}
				file.close();
			}
		}
	}
}

//init the actions
void MainWindow::createActions()
{
	
	actionOpen = new QAction(this);
	actionOpen->setIcon(QIcon(QString( ICON_PATH )+"/konsole.png"));
	actionOpen->setText(QApplication::tr("Open new QtOctave window"));

	actionRunFile = new QAction(this);
	actionRunFile->setIcon(QIcon(QString( ICON_PATH ) + "/run.png"));
	actionRunFile->setText(QApplication::tr("Run an Octave Script"));
	
	actionOctave_help = new QAction(this);
	actionOctave_help->setIcon(QIcon(QString( ICON_PATH )+"/help.png"));
	actionOctave_help->setText(QApplication::tr("Octave Help"));
	
	actionTable = new QAction(this);
	actionTable->setIcon(QIcon(QString( ICON_PATH )+"/table.png"));
	actionTable->setText(QApplication::tr("Table"));
	
	actionEditor = new QAction(this);
	actionEditor->setIcon(QIcon(QString( ICON_PATH )+"/xedit.png"));
	actionEditor->setText(QApplication::tr("Editor"));
	
	if(modeWorkArea=="dock")
	{
		actionOpenMFile = new QAction(this);
		actionOpenMFile->setText(QApplication::tr("Open .m file"));
	}
	
	actionProjects = new QAction(this);
	actionProjects->setIcon(QIcon(QString( ICON_PATH )+"/contents.png"));
	actionProjects->setText(QApplication::tr("Projects"));
	
	actionCompletionMatches= new QAction(this);
	actionCompletionMatches->setIcon(QIcon(QString( ICON_PATH )+"/search.png"));
	actionCompletionMatches->setText(QApplication::tr("<b>Completion matches:</b><br> Generates possible completions given in comand line."));
	
	actionDynamicHelp= new QAction(this);
	actionDynamicHelp->setIcon(QIcon(QString( ICON_PATH )+"/help_index.png"));
	actionDynamicHelp->setText(QApplication::tr("<b>Dynamic Help:</b><br> Shows help of completions matches."));
	
	actionStopProcess= new QAction(this);
	actionStopProcess->setIcon(QIcon(QString( ICON_PATH )+"/button_cancel.png"));
	actionStopProcess->setText(QApplication::tr("<b>Stops process:</b><br>Stops uncontroled process, infinite loops,..."));
	
	actionClearTerminal= new QAction(this);
	actionClearTerminal->setIcon(QIcon(QString( ICON_PATH )+ "/eraser.png"));
	actionClearTerminal->setText(QApplication::tr("<b>Clear terminal:</b><br>Erase terminal screen."));
	
	actionVariableList= new QAction(this);
	actionVariableList->setIcon(QIcon(QString( ICON_PATH )+ "/taskbar.png"));
	actionVariableList->setText(QApplication::tr("Variable List"));
	
	actionNavigator= new QAction(this);
	actionNavigator->setIcon(QIcon(QString( ICON_PATH )+ "/new_folder.png"));
	actionNavigator->setText(QApplication::tr("Navigator"));
	
	//Toolbars actions
	//actionToolBarDocks = new QAction("Docks", this);
	//actionToolBarDocks->setCheckable(true);
	//actionToolBarDocks->setChecked(true);
	//actionToolBarRun = new QAction("Terminal", this);
	//actionToolBarRun->setCheckable(true);
	//actionToolBarRun->setChecked(true);
	//actionToolBarMatrix = new QAction("Matrix", this);
	//actionToolBarMatrix->setCheckable(true);
	//actionToolBarMatrix->setChecked(true);
	//actionToolBarHelp = new QAction("Help", this);
	//actionToolBarHelp->setCheckable(true);
	//actionToolBarHelp->setChecked(true);
	
	//mode actions
	actionModeDock = new QAction("Dock", this);
	actionModeWorkspace = new QAction("Workspace", this);
	actionModeSDI = new QAction("Single Document Interface (SDI)", this);

	//Matrix actions
	actionInverse = new QAction(this);
	actionInverse->setText(QApplication::tr("Inverse"));
	
	actionDeterminant = new QAction(this);
	actionDeterminant->setText(QApplication::tr("Determinant"));
	
	actionEigenvalues = new QAction(this);
	actionEigenvalues->setText(QApplication::tr("Eigenvalues and eigenvectors"));
	
	actionTranspose = new QAction(this);
	actionTranspose->setText(QApplication::tr("Transpose"));
	
	actionSubmatrix = new QAction(this);
	actionSubmatrix->setText(QApplication::tr("Submatrix"));
	
	actionMean = new QAction(this);
	actionMean->setText(QApplication::tr("Mean"));
	
	actionMedian = new QAction(this);
	actionMedian->setText(QApplication::tr("Median"));
	
	actionStd = new QAction(this);
	actionStd->setText(QApplication::tr("Standard Deviation"));
	
	actionCov = new QAction(this);
	actionCov->setText(QApplication::tr("Covariance"));
	
	actionCorrcoef = new QAction(this);
	actionCorrcoef->setText(QApplication::tr("Correlation Coefficient"));
	
	//Plot actions
	actionPlot = new QAction(this);
	actionPlot->setText(QApplication::tr("Plot"));
	
	actionPolar = new QAction(this);
	actionPolar->setText(QApplication::tr("Polar"));
	
	actionSemilogy = new QAction(this);
	actionSemilogy->setText(QApplication::tr("Log scale for the y axis"));
	
	actionSemilogx = new QAction(this);
	actionSemilogx->setText(QApplication::tr("Log scale for the x axis"));
	
	actionLogLog = new QAction(this);
	actionLogLog->setText(QApplication::tr("Log scale for the x and y axis"));
	
	actionAxis = new QAction(this);
	actionAxis->setText(QApplication::tr("Axis scale"));
	
	actionTitleLabel = new QAction(this);
	actionTitleLabel->setText(QApplication::tr("Title and labels"));
	
	//actionToEPS  = new QAction(this);
	//actionToEPS->setText(QApplication::tr("EPS"));
	
	//actionToPDF  = new QAction(this);
	//actionToPDF->setText(QApplication::tr("PDF"));
	
	//actionToPNG  = new QAction(this);
	//actionToPNG->setText(QApplication::tr("PNG"));
	
	//Config actions
	actionGeneralConfig  = new QAction(this);
	actionGeneralConfig->setText(QApplication::tr("General configuration"));


	//connect the actions
	//connect(actionToolBarDocks, SIGNAL(triggered()), this, SLOT(setVisibleToolBarDocks()));
	//connect(actionToolBarRun, SIGNAL(triggered()), this, SLOT(setVisibleToolBarRun()));
	//connect(actionToolBarMatrix, SIGNAL(triggered()), this, SLOT(setVisibleToolBarMatrix()));
	//connect(actionToolBarHelp, SIGNAL(triggered()), this, SLOT(setVisibleToolBarHelp()));
	connect(actionModeWorkspace, SIGNAL(triggered()), this, SLOT(setModeWorkSpace()));
	connect(actionModeDock, SIGNAL(triggered()), this, SLOT(setModeDock()));
	connect(actionModeSDI, SIGNAL(triggered()), this, SLOT(setModeSDI()));
}

void MainWindow::createMenus()
{
	menubar = new QMenuBar(this);
	menuFile = createMenu(QString("/File"),QApplication::tr("File")); 
	menuHelp = createMenu("/Help", QApplication::tr("Help"));
	menuData = createMenu("/Data", QApplication::tr("Data"));
	menuMatrix = createMenu("/Matrix", QApplication::tr("Matrix"));
	menuStatistics = createMenu("/Statistics", QApplication::tr("Statistics"));
	menuPlot = createMenu("/Plot", QApplication::tr("Plot"));
	//menuExport = createMenu("/Plot/Export to...", QApplication::tr("Export to..."));
	menu2DPlot = createMenu("/Plot/2D...", QApplication::tr("2D..."));
	menuConfig = createMenu("/Config", QApplication::tr("Config"));
	menuView = createMenu("/View",QApplication::tr("View"));
	menuDocks = createMenu("/Docks", QApplication::tr("Docks"));
	menuMode = createMenu("/Mode",QApplication::tr("Mode"));
	//menuToolbars = createMenu("/Toolbars",QApplication::tr("Toolbars"));
	//Shows checks of visible toolbars
	//connect(menuToolbars, SIGNAL(triggered(QAction * )), this, SLOT(setVisibleToolBars(QAction * )));

	setMenuBar(menubar);

	//Add actions to menubar
	menubar->addAction(menuFile->menuAction());
	menubar->addAction(menuData->menuAction());
	menubar->addAction(menuMatrix->menuAction());
	menubar->addAction(menuStatistics->menuAction());
	menubar->addAction(menuPlot->menuAction());
	menubar->addAction(menuView->menuAction());
	
	menuFile->addAction(actionOpen);
	//menuFile->addAction(actionEditor);
	if(modeWorkArea=="dock")
	{
		menuFile->addAction(actionProjects);
		menuFile->addAction(actionOpenMFile);
	}
	menuFile->addAction(actionRunFile);
	menuFile->addAction(createAction("cd","Change Directory"));
	menuFile->addAction(createAction("exit","Quit",
			       QString( ICON_PATH ) + "/exit.png"));

	//Builds/Destroys menu View
	connect(menuView,SIGNAL(aboutToShow ()), this, SLOT(showSetVisibleObjects()) );
	connect(menuView,SIGNAL(aboutToHide ()), this, SLOT(hideSetVisibleObjects()) );
	
	menuData->addAction(actionTable);

	menuMatrix->addAction(createAction("+","A+B"));
	menuMatrix->addAction(createAction("*","A*B"));
	menuMatrix->addAction(createAction("**","A**n Exponential"));
	menuMatrix->addAction(actionDeterminant);
	menuMatrix->addAction(actionEigenvalues);
	menuMatrix->addAction(actionInverse);
	menuMatrix->addAction(actionTranspose);
	menuMatrix->addAction(actionSubmatrix);
	menuStatistics->addAction(actionMean);
	menuStatistics->addAction(actionMedian);
	menuStatistics->addAction(actionStd);
	menuStatistics->addAction(actionCov);
	menuStatistics->addAction(actionCorrcoef);
	menuStatistics->addAction(createAction("hist", "Histogram"));
	//menuPlot->addAction(menuExport->menuAction());
	menuPlot->addAction(menu2DPlot->menuAction());
	menuPlot->addAction(createMenu("menu3DPlot","3D...")->menuAction());
	menu2DPlot->addAction(actionPlot);
	menu2DPlot->addAction(actionPolar);
	menu2DPlot->addAction(actionLogLog);
	menu2DPlot->addAction(actionSemilogy);
	menu2DPlot->addAction(actionSemilogx);
	menu2DPlot->addAction(createAction("errorbar", "Error Bars"));
	menu2DPlot->addAction(createAction("hist", "Histogram"));
	menu2DPlot->addAction(createAction("bar", "Bar graph"));
	menus.value("menu3DPlot")->addAction(
			createAction("mesh","Plot of three-dimensional surface"));	
	menus.value("menu3DPlot")->addAction(
			createAction("contour","Contour plot of three-dimensional surface"));
	menuPlot->addAction(actionAxis);
	menuPlot->addAction(actionTitleLabel);
	//menuExport->addAction(actionToEPS);
	//menuExport->addAction(actionToPDF);
	//menuExport->addAction(actionToPNG);
}


void MainWindow::createMenuView()
{
	if (modeWorkArea != "dock")
	{
		menuView->addMenu(menuDocks);
		menuDocks->addAction(actionEditor);
		menuDocks->addAction(actionVariableList);
		menuDocks->addAction(actionNavigator);
	}
	
	
	//menuView->addMenu(menuToolbars);
	//menuToolbars->addAction(actionToolBarDocks);
	//menuToolbars->addAction(actionToolBarRun);
	//menuToolbars->addAction(actionToolBarMatrix);
	//menuToolbars->addAction(actionToolBarHelp);

	menuView->addMenu(menuMode);
	menuMode->addAction(actionModeWorkspace);
	menuMode->addAction(actionModeDock);
	menuMode->addAction(actionModeSDI);
	//Put checks  in View/Mode menus
	if ( modeWorkArea == "workspace")
	{
		actionModeWorkspace->setCheckable(true);
		actionModeWorkspace->setChecked(true);
	}
	else if(modeWorkArea == "sdi")
	{
		actionModeSDI->setCheckable(true);
		actionModeSDI->setChecked(true);
	}
	else if (modeWorkArea == "dock")
	{
		actionModeDock->setCheckable(true);
		actionModeDock->setChecked(true);
		QMenu *objects=((QMainWindow*)centralWidget())->createPopupMenu();
		objects->setTitle("Show/Hide Main Objects");
		menuView->addMenu(objects);
	}
	
	QMenu *objects=createPopupMenu();
	objects->setTitle("Show/Hide Objects");
	menuView->addMenu(objects);
}


void MainWindow::createStatusBar()
{
	statusbar = new QStatusBar(this);
	//statusbar->setGeometry(QRect(0, 396, 503, 22));
	setStatusBar(statusbar);
}


void MainWindow::createToolBars()
{
	toolBarRun = new QToolBar("Terminal Run", this) ;
	//toolBarRun->setOrientation(Qt::Horizontal);
	addToolBar(static_cast<Qt::ToolBarArea>(4), toolBarRun);
	toolBarRun->setObjectName("ToolBar: Terminal Run");

	toolBarMatrix = new QToolBar("Matrix", this);
	//toolBarMatrix->setOrientation(Qt::Horizontal);
	addToolBar(static_cast<Qt::ToolBarArea>(4), toolBarMatrix);
	toolBarMatrix->setObjectName("ToolBar: Matrix");

	toolBarHelp = new QToolBar("Help", this);
	addToolBar(static_cast<Qt::ToolBarArea>(4), toolBarHelp);
	toolBarHelp->setObjectName("ToolBar: Help");
	
	toolBarDocks = new QToolBar("Docks",this);
	toolBarDocks->setOrientation(Qt::Horizontal);
	addToolBar(static_cast<Qt::ToolBarArea>(4), toolBarDocks);
	toolBarDocks->setObjectName("ToolBar: Docks");


	//add to the toolbar docks
	//toolBarDocks->addAction(actionOpen); //This option is erased because doesn't work ok
	toolBarDocks->addAction(actionEditor);
	toolBarDocks->addAction(actionVariableList);
	toolBarDocks->addAction(actionNavigator);
	
	//add to the toolbar Matrix	
	toolBarMatrix->addAction(actionTable);
	//toolBar->addSeparator();
	
	//add to the toolbar Help
	toolBarHelp->addAction(actionOctave_help);
	toolBarHelp->addAction(actionDynamicHelp);
	toolBarHelp->addAction(actionCompletionMatches);
	//toolBar->addSeparator();
	
	//add to the toolbar run
	toolBarRun->addAction(actionRunFile);
	toolBarRun->addAction(actionStopProcess);
	toolBarRun->addAction(actionClearTerminal);
	//toolBar->addSeparator();


}

QAction *MainWindow::createAction(QString action_name, QString name, QString icon)
{
	return createAction(action_name, name.toLocal8Bit().data(), icon);
}

QAction *MainWindow::createAction(QString action_name, const char *name, QString icon)
{
	if( actions.contains(action_name) ) return actions[action_name];
	QAction *a = new QAction(this);
	if( !icon.isEmpty() ) a->setIcon(QIcon(icon));
	a->setText(QApplication::tr(name));
	actions[action_name]=a;
	return a;
}

QMenu *MainWindow::createMenu(QString menu_name, QString name, QString icon)
{
	return createMenu(menu_name, name.toLocal8Bit().data(), icon);
}

QMenu *MainWindow::createMenu(QString menu_name, const char *name, QString icon)
{
	if( menus.contains(menu_name) )
	       return menus[menu_name];

	QMenu *a = new QMenu(menubar);
	
	if(!icon.isEmpty())
	       a->setIcon(QIcon(icon));
	a->setTitle(QApplication::tr(name));
	menus[menu_name]=a;
	return a;
}

void MainWindow::clear_menu()
{
	menubar->clear();
}


void MainWindow::show_config_help_menus()
{
	menubar->addAction(menuConfig->menuAction());
	menubar->addAction(menuHelp->menuAction());
	
	menuConfig->addAction(actionGeneralConfig);
	//menuConfig->addAction(createAction("windows_layout","Windows Layout"));
	
	menuHelp->addAction(actionOctave_help);
	menuHelp->addAction(actionOctave_help);
	menuHelp->addAction(createAction("qtoctave_help","QtOctave Help"));
	menuHelp->addAction(createAction("qtoctave_about","About"));
}

void MainWindow::createDockWindows()
{
	//Editor dock and Terminal , only if the mode from work area is dock
	if(modeWorkArea == "dock")
	{
		//Variables list dock
		dockListVar = new QDockWidget(tr("Variable List"),this);
		dockListVar->setObjectName("Dock: Variable List");
		dockListVar->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
		//dockListVar->setMinimumSize(260,300);
		addDockWidget(Qt::LeftDockWidgetArea, dockListVar);
	
		//Navigator dock
		dockNavigator = new QDockWidget(tr("Navigator"),this);
		dockNavigator->setObjectName("Dock: Navigator");
		dockNavigator->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
		nav = Navigator::createNavigator();
		dockNavigator->setWidget(nav);
		//dockNavigator->setMinimumSize(260,300);
		addDockWidget(Qt::LeftDockWidgetArea, dockNavigator);
		nav->setOctaveConnection(octave_connection);
		
		dockCommandHistory = new QDockWidget(tr("Commands' History"),this);
		dockCommandHistory->setObjectName("Dock: Commands' History");
		dockCommandHistory->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
		//dockListVar->setMinimumSize(260,300);
		addDockWidget(Qt::RightDockWidgetArea, dockCommandHistory);

		QMainWindow *centralWindow=(QMainWindow *)centralWidget();
		//editter
		dockEditor = new QDockWidget(tr("Editor"),this);
		dockEditor->setObjectName("Dock: Editor");
		//dockEditor->setVisible(false);
		//dockEditor->setAllowedAreas(Qt::RightDockWidgetArea |
		//Qt::RightDockWidgetArea);
		dockEditor->setAllowedAreas(Qt::AllDockWidgetAreas);
		centralWindow -> addDockWidget(Qt::RightDockWidgetArea, dockEditor);

		//Terminal dock
		dockTerminal = new QDockWidget(tr("Terminal"),this);
		dockTerminal->setObjectName("Dock: Terminal");
		dockTerminal->setFeatures(QDockWidget::DockWidgetFloatable | QDockWidget::DockWidgetMovable);
		dockTerminal->setAllowedAreas(Qt::AllDockWidgetAreas);
		addDockWidget(Qt::RightDockWidgetArea, dockTerminal);
		centralWindow->addDockWidget(Qt::RightDockWidgetArea, dockTerminal);
	}
}


// void MainWindow::setVisibleToolBarDocks()
// {
// 	toolBarDocks->setVisible(!toolBarDocks->isVisible());
// }
// void MainWindow::setVisibleToolBarRun()
// {
// 	toolBarRun->setVisible(!toolBarRun->isVisible());
// }
// void MainWindow::setVisibleToolBarMatrix()
// {
// 	toolBarMatrix->setVisible(!toolBarMatrix->isVisible());
// }
// void MainWindow::setVisibleToolBarHelp()
// {
// 	toolBarHelp->setVisible(!toolBarHelp->isVisible());
// }

void MainWindow::setModeSDI()
{
	modeWorkArea = "sdi";

	if(closeMessage->exec() == QMessageBox::Yes)
		close();
}

void MainWindow::setModeWorkSpace()
{
	modeWorkArea = "workspace";

	if(closeMessage->exec() == QMessageBox::Yes)
		close();
}

void MainWindow::setModeDock()
{
	modeWorkArea = "dock";
	if(closeMessage->exec() == QMessageBox::Yes)
		close();
}



void MainWindow::closeEvent(QCloseEvent *event)
{
	int ok=QMessageBox::question(this, tr("Close"), tr("You are going to close all QtOctave's windows. Are you sure?"), QMessageBox::Yes, QMessageBox::No );
	
	if(ok!=QMessageBox::Yes)
	{
		event->ignore ();
		return;
	}
	
	QString mode = get_config("mode_work_area");	
	if ( mode == "workspace" || mode == "sdi" )
	{
		foreach (QWidget *widget, QApplication::topLevelWidgets())
		{
			if(widget!=this) widget->close();
		}
	}
	else if (mode == "dock")
	{
		windowSettings["dock_navigator_visible"] = (dockNavigator->isVisible())?"true":"false";
		
		QByteArray data;
		QString home=QDir::home().path()+"/.qtoctave/";
		{
			data=saveState();
			QFile file(home+"qtoctave_state.dat");
			if (file.open(QIODevice::WriteOnly | QIODevice::Text))
			{
				file.write(data);
				file.close();
			}
		}
		{
			data=((QMainWindow*)centralWidget())->saveState();
			QFile file(home+"qtoctave_central_state.dat");
			if (file.open(QIODevice::WriteOnly | QIODevice::Text))
			{
				file.write(data);
				file.close();
			}
		}
	}
	windowSettings["mode_work_area"] = modeWorkArea;
	
	set_config(windowSettings);
	
	QApplication::quit();
	//exit(0);
}

void MainWindow::showSetVisibleObjects()
{
	createMenuView();
}

void MainWindow::hideSetVisibleObjects()
{
	menuView->clear();
}

